@@ -96,6 +96,7 @@ class Main(object):
                                   'port': default_port,
                                   'bind-address': default_address,
                                   'workers': default_workers,
+                                  'memcache': None,
                                   'max-cons-per-ip': '0',
                                   'auth-url': None,
                                   'service-net': 'no',
@@ -137,6 +138,16 @@ class Main(object):
                           help="Number of workers to use default: %d." % \
                               (default_workers))
 
+        memcache = self.config.get('ftpcloudfs', 'memcache')
+        if memcache:
+            memcache = [x.strip() for x in memcache.split(',')]
+        parser.add_option('--memcache',
+                          type="str",
+                          dest="memcache",
+                          action="append",
+                          default=memcache,
+                          help="Memcache server(s) to be used for cache (ip:port).")
+
         parser.add_option('-a', '--auth-url',
                           type="str",
                           dest="authurl",
@@ -207,6 +218,9 @@ class Main(object):
         MyFTPHandler.banner = banner
         RackspaceCloudFilesFS.servicenet = self.options.servicenet
         RackspaceCloudFilesFS.authurl = self.options.authurl
+        RackspaceCloudFilesFS.memcache_hosts = self.options.memcache
+        if self.options.workers > 1 and not self.options.memcache:
+            RackspaceCloudFilesFS.single_cache = False
 
         masquerade = self.config.get('ftpcloudfs', 'masquerade-firewall')
         if masquerade:
